@@ -51,6 +51,8 @@ class Travel(models.Model):
 
 class Report(models.Model):
     report_id = models.PositiveIntegerField()
+    filer_id = OptionalMaxCharField()  # TODO: reference actual tx_people.Identifier for tec.
+    filer_type = OptionalMaxCharField()  # TODO: see above
     report_number = models.PositiveIntegerField(default=0)
     is_original = models.BooleanField(default=True)
     from_date = models.DateField()
